@@ -22,6 +22,7 @@ Using pdf2xml as a library is possible via the pdf2xml function:
 
  %options = (
     conversion_tool         => 'pdfXtk',        # use pdfXtk (default = 'tika')
+    keep_vocabulary         => 1,               # don't reset the vocabulary
     vocabulary              => 'filename',      # plain text file
     vocabulary_from_pdf     => 0,               # skip pdftotext
     vocabulary_from_raw_pdf => 0,               # skip pdftotext -raw
@@ -40,6 +41,8 @@ Using pdf2xml as a library is possible via the pdf2xml function:
 
  pdf2xml( $pdf_file, output => 'file.xml', %options );
 
+Note that the options stay for the next pdf2xml call! You need to overwrite them if you want to change the behaviour in subsquent calls while the libraray is loaded!
+
 
 =head1 DESCRIPTION
 
@@ -88,6 +91,7 @@ package Text::PDF2XML;
 
 use strict;
 
+use Encode::Locale;
 use Encode qw/decode_utf8/;
 use File::Temp qw /tempfile/;
 use FindBin qw/$Bin/;
@@ -102,17 +106,13 @@ use Exporter 'import';
 our @EXPORT = qw(pdf2xml);
 our %EXPORT_TAGS = ( all => \@EXPORT );
 
-
-
-
-our $TIKA_URL        = 'http://localhost:9998';
-our $USE_TIKA_SERVER = 1;
-
-
-my $SHARED_HOME;
 eval{ 
     require Lingua::Identify::Blacklists;
-    require File::ShareDir; 
+};
+
+my $SHARED_HOME = undef;
+eval{ 
+    require File::ShareDir;
     $SHARED_HOME = File::ShareDir::dist_dir('Text-PDF2XML'); 
 };
 
@@ -124,11 +124,40 @@ unless (-e $SHARED_HOME.'/lib/tika-app-1.18.jar'){
     }
 }
 
-## Apache Tika Server
+
+# global parameters
+
+our $TIKA_URL        = 'http://localhost:9998';
+our $USE_TIKA_SERVER = 1;
+our $CONVERTER       = 'tika';
+
+our $JAVA            = 'java';
+our $JAVA_HEAP_SIZE  = '1g';
+our $TIKAJAR         = $SHARED_HOME.'/lib/tika-app-1.18.jar';
+our $PDF2TEXT        = `which pdftotext`;chomp($PDF2TEXT);
+
+our $LOWERCASE       = 1;
+our $SPLIT_CHAR      = 0;
+our $CHAR_MERGING    = 1;
+our $PAR_MERGING     = 1;
+our $DEHYPHENATE     = 1;
+our $DETECT_LANG     = 0;
+our $KEEP_LANG       = undef;
+
+our $KEEP_VOCABULARY = 0;
+our $VOCAB_FROM_PDF  = 0;
+our $VOCAB_FROM_RAW  = 1;
+our $VOCAB_FROM_TIKA = 0;
+
+our $VERBOSE         = 0;
+
+
+
+## check availability of the Apache Tika Server
 my $_UserAgent;
 if ($USE_TIKA_SERVER){
     $_UserAgent    = LWP::UserAgent->new();
-    my $_request   = HTTP::Request->new('HEAD' => 'http://localhost:9998');
+    my $_request   = HTTP::Request->new('HEAD' => $TIKA_URL);
     my $_response  = $_UserAgent->request($_request);
     if ($_response->is_error) {
 	# print "Apache Tika Server is not available!\n";
@@ -136,37 +165,21 @@ if ($USE_TIKA_SERVER){
     }
 }
 
-our $CONVERTER      = 'tika';
 
-our $JAVA           = 'java';
-our $JAVA_HEAP_SIZE = '1g';
-our $TIKAJAR        = $SHARED_HOME.'/lib/tika-app-1.18.jar';
-our $PDF2TEXT       = `which pdftotext`;chomp($PDF2TEXT);
-
-our $LOWERCASE      = 1;
-our $CHAR_MERGING   = 1;
-our $PAR_MERGING    = 1;
-our $DEHYPHENATE    = 1;
-our $DETECT_LANG    = 0;
-our $KEEP_LANG      = undef;
-
-our $VOCAB_FROM_PDF  = 0;
-our $VOCAB_FROM_RAW  = 1;
-our $VOCAB_FROM_TIKA = 0;
-
-our $VERBOSE        = 0;
-
-# some global variables used for finding words in strings
-# LONGEST_WORD = length of the longest word in the vocabulary
+## a special variable for pdfXtk:
+#
 # SPLIT_CHAR_IF_NECESSARY = split strings into character sequences
 #                           (if they do not contain any single whitespace)
-#                           (this is only used with pdfxtk output)
-# SPLIT_CHAR = always split strings into character sequence before finding words
 
-
-our $LONGEST_WORD            = undef;
 our $SPLIT_CHAR_IF_NECESSARY = 0;
-our $SPLIT_CHAR              = 0;
+
+
+## voacabulary and unigram LM
+# LONGEST_WORD = length of the longest word in the vocabulary
+
+our %voc          = ();
+our %lm           = ();
+our $LONGEST_WORD = undef;
 
 
 # we require recent versions of pdftotext developed by 
@@ -189,7 +202,7 @@ my %LIGATURES = (
 my $LIGATURES_MATCH = join('|',sort {length($b) <=> length($a)} 
 			   keys %LIGATURES);
 
-
+# XML writer handle
 my $XMLWRITER = undef;
 
 #-------------------------------------------------------
@@ -202,10 +215,13 @@ sub pdf2xml{
     my $pdf_file = shift;
     my %options = @_;
 
+    die "no input file '$pdf_file' found" unless (-e $pdf_file);
+
     $CONVERTER       = $options{conversion_tool} if ($options{conversion_tool});
     $USE_TIKA_SERVER = $options{use_tika_server} if (defined $options{use_tika_server});
     $TIKA_URL        = $options{tika_url} if ($options{tika_url});
 
+    $KEEP_VOCABULARY = $options{keep_vocabulary} if ($options{keep_vocabulary});
     $VOCAB_FROM_PDF  = $options{vocabulary_from_pdf} if (defined $options{vocabulary_from_pdf});
     $VOCAB_FROM_RAW  = $options{vocabulary_from_raw_pdf} if (defined $options{vocabulary_from_raw_pdf});
     $VOCAB_FROM_TIKA = $options{vocabulary_from_tika} if (defined $options{vocabulary_from_tika});
@@ -223,6 +239,12 @@ sub pdf2xml{
 
     $VERBOSE         = $options{verbose} if ($options{verbose});
 
+    ## reset vocabulary
+    unless ($KEEP_VOCABULARY){
+	%voc = ();
+	%lm = ();
+	$LONGEST_WORD = undef;
+    }
 
     if ($options{vocabulary}){
 	&read_vocabulary($options{vocabulary});
@@ -251,11 +273,11 @@ sub pdf2xml{
 	$output = \$result;
     }
 
-    binmode(STDOUT,":encoding(UTF-8)");
-    binmode(STDERR,":encoding(UTF-8)");
+    binmode(STDOUT,":encoding(locale)");
+    binmode(STDERR,":encoding(locale)");
 
     # binmode(STDOUT,":encoding(UTF-8)");
-    # $XMLWRITER = XML::Writer->new( OUTPUT => \*STDOUT, 
+    # binmode(STDERR,":encoding(UTF-8)");
 
     $XMLWRITER = XML::Writer->new( OUTPUT => $output,
 				   DATA_MODE => 1,
@@ -276,6 +298,7 @@ sub pdf2xml{
 	my $out_file = &_run_pdfxtk($pdf_file);
 	open OUT,"<$out_file" || die "cannot read from pdfxtkoutput ($out_file)\n";
 	binmode(OUT,":encoding(UTF-8)");
+	# binmode(OUT,":encoding(locale)");
 	$SPLIT_CHAR_IF_NECESSARY = 1;
 	my $handler = $parser->parse_start;
 	while (<OUT>){
@@ -292,6 +315,7 @@ sub pdf2xml{
 	    $parser->parse($ParsedContent);
 	}
 	else {
+	    local $ENV{LC_ALL} = 'en_US.UTF-8';
 	    my $pid = open3(undef, \*OUT, \*ERR, $JAVA,'-Xmx'.$JAVA_HEAP_SIZE,
 			    '-jar',$TIKAJAR,'-x',$pdf_file);
 	    $parser->parse(*OUT);
@@ -309,11 +333,6 @@ sub pdf2xml{
 
 
 
-## voacabulary and unigram LM
-
-our %voc = ();
-our %lm  = ();
-
 
 sub read_vocabulary{
     my $file = shift;
@@ -402,6 +421,7 @@ sub _run_pdfxtk{
     ## ---------------------------
 
     # print STDERR "$JAVA16 -Xmx $JAVA_HEAP_SIZE -cp $CLASSPATH at.ac.tuwien.dbai.pdfwrap.ProcessFile $pdf_file $out_file\n";
+    local $ENV{LC_ALL} = 'en_US.UTF-8';
     my $pid = open3(undef, undef, undef, 
 		    $JAVA16,
 		    '-Xmx'.$JAVA_HEAP_SIZE,
@@ -440,9 +460,6 @@ sub _xml_end{
 	    my $DehyphenatedStr = undef;
 
 	    if ($DEHYPHENATE){
-		if ($OriginalStr=~/facili\-/){
-		    print '';
-		}
 		while ($OriginalStr=~/\-\s*$/ && @lines){
 		    $DehyphenatedStr = $OriginalStr unless ($DehyphenatedStr);
 		    $DehyphenatedStr=~s/\-\s*$//;
@@ -556,6 +573,7 @@ sub _xml_end_simple{
 sub _vocab_from_pdftotext_raw{
     my $pdf_file = shift;
 
+    local $ENV{LC_ALL} = 'en_US.UTF-8';
     my $pid = open3(undef, \*OUT, \*ERR, $PDF2TEXT,'-raw','-enc','UTF-8',$pdf_file,'-');
 
     binmode(OUT,":encoding(UTF-8)");
@@ -574,6 +592,7 @@ sub _vocab_from_pdftotext{
     my $pdf_file = shift;
 
     return &_vocab_from_tika($pdf_file) unless ( -e $PDF2TEXT );
+    local $ENV{LC_ALL} = 'en_US.UTF-8';
     my $pid = open3(undef, \*OUT, \*ERR, 'pdftotext','-enc','UTF-8',$pdf_file,'-');
 
     binmode(OUT,":encoding(UTF-8)");
@@ -602,6 +621,7 @@ sub _vocab_from_tika{
 	return 1;
     }
 
+    local $ENV{LC_ALL} = 'en_US.UTF-8';
     my $pid = open3(undef, \*OUT, \*ERR, $JAVA,'-Xmx'.$JAVA_HEAP_SIZE,
 		    '-jar',$TIKAJAR,'-t',$pdf_file);
 
